min_len_for_work

Function min_len_for_work 

pub fn min_len_for_work(work: WorkPerItem) -> usize
Minimum items per task for a loop bound by arithmetic.

Arguments

  • work - cost class of one item of the loop

Returns

The number of items one task must take to fill the time budget.