pub fn task_chunk_len<T>() -> usize
Elements per chunk so one chunk spans the byte budget.
Use this directly as the chunk size of a chunked parallel loop. The chunk size already is the floor, so no further floor is needed.